==> Gifi_0.4-0.tar.gz: Gifi/man/homals.Rd <==
\name{homals}
\alias{homals}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Multiple Correspondence Analysis (HOMALS). 
}
\description{
Fits a multiple correspondence analysis (MCA). The default is to take each input variable as nominal. Through restrictions on the transformations (ordinal in conjunction with splines) various generalizations of MCA can be achieved. 
}
\usage{
homals(data, ndim = 2, levels = "nominal", ordinal, knots, ties = "s", 
degrees = -1, missing = "s", normobj.z = TRUE, active = TRUE, itmax = 1000, 
eps = 1e-6, verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{Input data frame: n observations, m variables}
  \item{ndim}{Number of dimensions to be computed}
  \item{levels}{A vector of length m denoting basic scale levels (\code{"nominal"}, \code{"ordinal"}, \code{"metric"}; see details}
  \item{ordinal}{If knots are specified manually, a boolean vector of length m denotes which variables should be ordinally restricted or not (see details)}
  \item{knots}{Scale levels can be specified manually using splines (see \code{\link{knotsGifi}}). If knots is set, this overrides \code{level} (see details)}
  \item{ties}{How ties should be handled: primary (\code{"p"}), secondary (\code{"s"}), or tertiary (\code{"t"})}
  \item{degrees}{Spline degrees. If different degrees should be used across variables, a vector of length m can be specified. The default value of -1 indicates nominal scale level (overrides the ordinal argument).}
  \item{missing}{How missing values should be handled: multiple (\code{"m"}), single (\code{"s"}), or average (\code{"a"})}
  \item{active}{Which variables should be active or inactive (also as vector of length m)}
  \item{normobj.z}{If \code{TRUE}, object scores are z-scores, if \code{FALSE}, they are restricted to SS of 1.}
  \item{itmax}{Maximum number of iterations}
  \item{eps}{Convergence criterion}
  \item{verbose}{Iteration printout}
}
\details{
The measurement (or scale) levels of the variables are incorporated via spline transformations. If the user only needs simple scale levels like nominal, ordinal, and metric, a corresponding vector can be specified in the \code{levels} argument without setting \code{knots} and \code{ordinal}. The corresponding spline transformations (unrestricted, monotone, and linear) are then created internally. If all scale level transformations are the same, \code{ordinal} can be a single value. For more advanced transformations such as polynomial or more flexible splines, the \code{knots} and \code{ordinal} arguments need to be specified instead of \code{levels}. 
}
\value{
\item{transform}{Optimally transformed scores}
\item{rhat}{Induced correlation matrix}
\item{evals}{Eigenvalues of induced correlation matrix}
\item{objectscores}{Object scores (rows)}
\item{scoremat}{Optimally scaled data matrix (first dimension)}
\item{quantifications}{Category quantifications}
\item{dmeasures}{Discimination matrices}
\item{lambda}{Average discrimination matrix}
\item{weights}{Component weights}
\item{loadings}{Component loadings}
\item{ntel}{Number of iterations}
\item{f}{Loss function value}
\item{data}{Original data frame}
\item{datanum}{Numerical data frame}
\item{ndim}{Number of extracted dimensions}
\item{call}{Function call}
}
\references{
Gifi, A. (1990). Nonlinear Multivariate Analysis. New York: Wiley.

De Leeuw, J., Mair, P., Groenen, P. J. F. (2017). Multivariate Analysis with Optimal Scaling.
}
\seealso{\code{\link{princals}}, \code{\link{plot.homals}}}
\examples{
## multiple CA 
fithart <- homals(hartigan)
fithart
summary(fithart)
}
\keyword{multivariate}% use one of  RShowDoc("KEYWORDS")

==> Gifi_1.0-0.tar.gz: Gifi/man/homals.Rd <==
\name{homals}
\alias{homals}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Multiple Correspondence Analysis (HOMALS). 
}
\description{
Fits a multiple correspondence analysis (MCA). The default is to take each input variable as nominal. Through restrictions on the transformations (ordinal in conjunction with splines) various generalizations of MCA can be achieved. 
}
\usage{
homals(data, ndim = 2, levels = "nominal", ordinal, knots, ties = "s", 
degrees = -1, missing = "s", normobj.z = TRUE, active = TRUE, itmax = 1000, 
eps = 1e-6, verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data}{Input data frame: n observations, m variables}
  \item{ndim}{Number of dimensions to be computed}
  \item{levels}{A vector of length m denoting basic scale levels (\code{"nominal"}, \code{"ordinal"}, \code{"metric"}; see details}
  \item{ordinal}{If knots are specified manually, a boolean vector of length m denotes which variables should be ordinally restricted or not (see details)}
  \item{knots}{Scale levels can be specified manually using splines (see \code{\link{knotsGifi}}). If knots is set, this overrides \code{level} (see details)}
  \item{ties}{How ties should be handled: primary (\code{"p"}), secondary (\code{"s"}), or tertiary (\code{"t"})}
  \item{degrees}{Spline degrees. If different degrees should be used across variables, a vector of length m can be specified. The default value of -1 indicates nominal scale level (overrides the ordinal argument).}
  \item{missing}{How missing values should be handled: multiple (\code{"m"}), single (\code{"s"}), or average (\code{"a"})}
  \item{active}{Which variables should be active or inactive (also as vector of length m)}
  \item{normobj.z}{If \code{TRUE}, object scores are z-scores, if \code{FALSE}, they are restriction to SS of 1.}
  \item{itmax}{Maximum number of iterations}
  \item{eps}{Convergence criterion}
  \item{verbose}{Iteration printout}
}
\details{
The measurement (or scale) levels of the variables are incorporated via spline transformations. If the user only needs simple scale levels like nominal, ordinal, and metric, a corresponding vector can be specified in the \code{levels} argument without setting \code{knots} and \code{ordinal}. The corresponding spline transformations (unrestricted, monotone, and linear) are then created internally. If all scale level transformations are the same, \code{ordinal} can be a single value. For more advanced transformations such as polynomial or more flexible splines, the \code{knots} and \code{ordinal} arguments need to be specified instead of \code{levels}. 
}
\value{
\item{transform}{Optimally transformed scores}
\item{rhat}{Induced correlation matrix}
\item{evals}{Eigenvalues of induced correlation matrix}
\item{objectscores}{Object scores (rows)}
\item{scoremat}{Optimally scaled data matrix (first dimension)}
\item{quantifications}{Category quantifications}
\item{dmeasures}{Discimination matrices}
\item{lambda}{Average discrimination matrix}
\item{weights}{Component weights}
\item{loadings}{Component loadings}
\item{ntel}{Number of iterations}
\item{f}{Loss function value}
\item{data}{Original data frame}
\item{datanum}{Numerical data frame}
\item{ndim}{Number of extracted dimensions}
\item{call}{Function call}
}
\references{
Gifi, A. (1990). Nonlinear Multivariate Analysis. New York: Wiley.

De Leeuw, J., Mair, P., Groenen, P. J. F. (2017). Multivariate Analysis with Optimal Scaling.
}
\seealso{\code{\link{princals}}, \code{\link{plot.homals}}}
\examples{
## multiple CA 
fithart <- homals(hartigan)
fithart
summary(fithart)
}
\keyword{multivariate}% use one of  RShowDoc("KEYWORDS")
